@@ -67,6 +67,7 @@ class Recipe:
                    'WAIT_INTERVAL':'number',
                    'ADD_MESSAGEID':'number',
                    'SUPERVISED_DAEMON':'number',
+                   'MAILDROP_USER':'string',
                   }
         
         # prepare list of values
@@ -120,7 +121,7 @@ class Recipe:
                 processed = True
             if line.startswith('MAILDROP_USER'):
                 # maildrop user will be read from options or will be the same as current user
-                v = self.options.get('MAILDROPN_USER')
+                v = self.options.get('MAILDROP_USER')
                 if v is not None:
                     new_ctl.write('MAILDROP_USER="%s"\n' % v)
                 else:
